Citation Guidelines
===================

|JOSS| |Zenodo|


If you use SkyPy for work or research presented in a publication (whether
directly, or as a dependency of another package) we recommend and encourage
the following acknowledgment:

  This research made use of SkyPy, a Python package for forward modeling
  astronomical surveys (Amara et. al., 2021, SkyPy Collaboration, 202x).

where the citations are to our publication in the `Journal of Open Source
Software`_ and the `Zenodo DOI`_ for the specific version of the software that
you used. We also encourage citations within the main text wherever
appropriate. DOIs and BibTeX keys are available through the links above.

.. _Journal of Open Source Software: https://joss.theoj.org/papers/10.21105/joss.03056
.. _Zenodo DOI: https://zenodo.org/record/3755531


.. |JOSS| image:: https://joss.theoj.org/papers/10.21105/joss.03056/status.svg
    :target: https://doi.org/10.21105/joss.03056

.. |Zenodo| image:: https://zenodo.org/badge/doi/10.5281/zenodo.4475347.svg
    :target: https://doi.org/10.5281/zenodo.3755531
